/*
 * Copyright (C) 2011 Baidu Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#ifndef FFMPEG_API_H
#define FFMPEG_API_H

#ifdef __cplusplus
extern "C" {
#endif

enum {
    FF_FAIL = -1,
    FF_OK,
    FF_UNSUPPORTCODEC,
    FF_BITSEND,
    FF_EXCEPTION
};

typedef struct __fflibfrmbuf_tag {
    unsigned char *base;    
    unsigned char *yuv[3];      /* y,u,v */
    int            pitch[3];    /* y,u,v */
    int            pic_width;
    int            pic_height;
    unsigned int   pixel_format;
    int            *reserved;
} FFLIBFRMBUF;

typedef struct
{
    int width;
    int height;
    int sample_rate;
    int bit_rate;
    int bits_per_sample;
    int block_align;
    int play_time;
    unsigned int format_tag;
    unsigned char *extradata;
    int extradata_size;
    int channels;

} MetaConfig_t;

typedef struct
{
    int user_buffer_flag;
    void* buf_man_handle;
    int omx_flag;
}BufManConfig_t;

#define MAX_VIDEO_OUTPUTBUFFER_NUM 6
#define MAX_PADDING_WIDTH 32
#define ALIGN_SIZE 32
#define ALIGN(x, a) (((x)+(a)-1)&~((a)-1))


// video only for the time being
void* FFAPI_InitCodec(MetaConfig_t *metaConfig, int iCodecID, BufManConfig_t *bufManConfig);
int  FFAPI_SetExtraData(void* handle,MetaConfig_t *pucExtraData);
int  FFAPI_Decode(void* handle,const unsigned char * pucStreamBuffer, 
            int iSize,int * piBytesConsumed, int *videoDecdeEnd,
            int *piOutSize,short* pOutputBuffer);
int  FFAPI_GetFrameBuffer(void* handle,FFLIBFRMBUF *pFrame);
void FFAPI_Reset(void* handle);
void FFAPI_FlushBuffers(void* handle);
void FFAPI_FreeCodec(void* handle);


void FFAPI_DisplayFrameInfo(const FFLIBFRMBUF* pFrame);

#ifdef __cplusplus
}
#endif

#endif
